@@ -3,11 +3,10 @@ package GraphQL::Execution;
 use 5.014;
 use strict;
 use warnings;
-use Return::Type;
 use Types::Standard -all;
 use Types::TypeTiny -all;
 use GraphQL::Type::Library -all;
-use Function::Parameters;
+use GraphQL::MaybeTypeCheck;
 use GraphQL::Language::Parser qw(parse);
 use GraphQL::Error;
 use JSON::MaybeXS;
@@ -18,6 +17,7 @@ use GraphQL::Introspection qw(
 use GraphQL::Directive;
 use GraphQL::Schema qw(lookup_type);
 use Exporter 'import';
+use Scalar::Util qw(blessed);
 
 =head1 NAME
 
@@ -751,11 +751,14 @@ fun _default_field_resolver(
     ? $root_value->{$field_name}
     : $root_value;
   DEBUG and _debug('_default_field_resolver', $root_value, $field_name, $args, $property);
-  if (eval { CodeLike->($property); 1 }) {
+  if (length(ref $property) and (
+    ref($property) eq 'CODE' or
+    (blessed $property and overload::Method($property, '&{}'))
+  )) {
     DEBUG and _debug('_default_field_resolver', 'codelike');
     return $property->($args, $context, $info);
   }
-  if (is_InstanceOf($root_value) and $root_value->can($field_name)) {
+  if (length(ref $root_value) and blessed($root_value) and $root_value->can($field_name)) {
     DEBUG and _debug('_default_field_resolver', 'method');
     return $root_value->$field_name($args, $context, $info);
   }
