@@ -274,8 +274,8 @@ sub _make_moo_field {
   my ($field_name, $type) = @_;
   ($field_name => { resolve => sub {
     my ($root_value, $args, $context, $info) = @_;
-    my @passon = %$args ? ($args) : ();
     return undef unless $root_value->can($field_name);
+    my @passon = %$args ? ($args) : ();
     $root_value->$field_name(@passon);
   }, type => $type });
 }
@@ -443,7 +443,13 @@ $TYPE_META_TYPE = GraphQL::Type::Object->new(
       type => $TYPE_KIND_META_TYPE->non_null,
       resolve => sub { my $c = ref $_[0]; $c =~ s#__.*##; CLASS2KIND->{$c} // die "Unknown kind of type => ".ref $_[0] },
     },
-    _make_moo_field(name => $String),
+    name => { resolve => sub {
+      my ($root_value, $args, $context, $info) = @_;
+      # if not a "real" name
+      return undef if $root_value->can('of');
+      my @passon = %$args ? ($args) : ();
+      $root_value->name(@passon);
+    }, type => $String },
     _make_moo_field(description => $String),
     fields => {
       type => $FIELD_META_TYPE->non_null->list,
