@@ -6,8 +6,7 @@ use warnings;
 use Moo;
 use Types::Standard -all;
 use GraphQL::Type::Library -all;
-use Function::Parameters;
-use Return::Type;
+use GraphQL::MaybeTypeCheck;
 use GraphQL::Debug qw(_debug);
 extends qw(GraphQL::Type);
 with qw(GraphQL::Role::Nullable);
